@@ -37,6 +37,8 @@
  * Interfaces for reading Ogg files and streams
  */
 
+#include <oggz/oggz_packet.h>
+
 /** \defgroup read_api Oggz Read API
  *
  * Oggz parses Ogg bitstreams, forming ogg_packet structures, and calling
@@ -67,16 +69,16 @@
  * with \a oggz.
  *
  * \param oggz The OGGZ handle
- * \param op The full ogg_packet (see <ogg/ogg.h>)
+ * \param packet The packet, including its position in the stream.
  * \param serialno Identify the logical bistream in \a oggz that contains
- *                 \a op
+ *                 \a packet
  * \param user_data A generic pointer you have provided earlier
  * \returns 0 to continue, non-zero to instruct Oggz to stop.
  *
  * \note It is possible to provide different callbacks per logical
  * bitstream -- see oggz_set_read_callback() for more information.
  */
-typedef int (*OggzReadPacket) (OGGZ * oggz, ogg_packet * op, long serialno,
+typedef int (*OggzReadPacket) (OGGZ * oggz, oggz_packet * packet, long serialno,
 			       void * user_data);
 
 /**
@@ -94,6 +96,7 @@ typedef int (*OggzReadPacket) (OGGZ * oggz, ogg_packet * op, long serialno,
  * logical bitstream in \a oggz.
  * \retval OGGZ_ERR_BAD_OGGZ \a oggz does not refer to an existing OGGZ
  * \retval OGGZ_ERR_INVALID Operation not suitable for this OGGZ
+ * \retval OGGZ_ERR_OUT_OF_MEMORY Out of memory
  *
  * \note Values of \a serialno other than -1 allows you to specify different
  * callback functions for each logical bitstream.
@@ -131,6 +134,7 @@ typedef int (*OggzReadPage) (OGGZ * oggz, const ogg_page * og,
  * \retval 0 Success
  * \retval OGGZ_ERR_BAD_OGGZ \a oggz does not refer to an existing OGGZ
  * \retval OGGZ_ERR_INVALID Operation not suitable for this OGGZ
+ * \retval OGGZ_ERR_OUT_OF_MEMORY Out of memory
  *
  * \note Values of \a serialno other than -1 allows you to specify different
  * callback functions for each logical bitstream.
@@ -156,6 +160,8 @@ int oggz_set_read_page (OGGZ * oggz, long serialno,
  * returning OGGZ_STOP_OK
  * \retval OGGZ_ERR_STOP_ERR Reading was stopped by a user callback
  * returning OGGZ_STOP_ERR
+ * \retval OGGZ_ERR_HOLE_IN_DATA Hole (sequence number gap) detected in input data
+ * \retval OGGZ_ERR_OUT_OF_MEMORY Out of memory
  */
 long oggz_read (OGGZ * oggz, long n);
 
@@ -171,6 +177,8 @@ long oggz_read (OGGZ * oggz, long n);
  * returning OGGZ_STOP_OK
  * \retval OGGZ_ERR_STOP_ERR Reading was stopped by a user callback
  * returning OGGZ_STOP_ERR
+ * \retval OGGZ_ERR_HOLE_IN_DATA Hole (sequence number gap) detected in input data
+ * \retval OGGZ_ERR_OUT_OF_MEMORY Out of memory
  */
 long oggz_read_input (OGGZ * oggz, unsigned char * buf, long n);
 
