@@ -31,7 +31,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <oggz/oggz.h>
+#include "oggz/oggz.h"
 
 #define ID_WRITE_DIRECT
 /* define USE_FLUSH_NEXT */
@@ -60,8 +60,9 @@ read_page (OGGZ * oggz, const ogg_page * og, long serialno, void * user_data)
 }
 
 static int
-read_packet (OGGZ * oggz, ogg_packet * op, long serialno, void * user_data)
+read_packet (OGGZ * oggz, oggz_packet * zp, long serialno, void * user_data)
 {
+  ogg_packet * op = &zp->op;
   MHData * mhdata = (MHData *)user_data;
   int flush;
   int ret;
