@@ -45,7 +45,7 @@
 #include "oggz_byteorder.h"
 #include "dirac.h"
 
-#include <oggz/oggz_stream.h>
+#include "oggz/oggz_stream.h"
 
 /*#define DEBUG*/
 
@@ -58,11 +58,6 @@ int oggz_set_metric_linear (OGGZ * oggz, long serialno,
 			    ogg_int64_t granule_rate_numerator,
 			    ogg_int64_t granule_rate_denominator);
 
-#define INT16_BE_AT(x) _be_16((*(ogg_int32_t *)(x)))
-#define INT32_LE_AT(x) _le_32((*(ogg_int32_t *)(x)))
-#define INT32_BE_AT(x) _be_32((*(ogg_int32_t *)(x)))
-#define INT64_LE_AT(x) _le_64((*(ogg_int64_t *)(x)))
-
 static int
 oggz_stream_set_numheaders (OGGZ * oggz, long serialno, int numheaders)
 {
@@ -87,7 +82,7 @@ auto_speex (OGGZ * oggz, long serialno, unsigned char * data, long length, void
 
   if (length < 68) return 0;
 
-  granule_rate = (ogg_int64_t) INT32_LE_AT(&header[36]);
+  granule_rate = (ogg_int64_t) int32_le_at(&header[36]);
 #ifdef DEBUG
   printf ("Got speex rate %d\n", (int)granule_rate);
 #endif
@@ -96,7 +91,7 @@ auto_speex (OGGZ * oggz, long serialno, unsigned char * data, long length, void
 
   oggz_set_preroll (oggz, serialno, 3);
 
-  numheaders = (ogg_int64_t) INT32_LE_AT(&header[68]) + 2;
+  numheaders = (ogg_int64_t) int32_le_at(&header[68]) + 2;
   oggz_stream_set_numheaders (oggz, serialno, numheaders);
 
   return 1;
@@ -110,7 +105,7 @@ auto_vorbis (OGGZ * oggz, long serialno, unsigned char * data, long length, void
 
   if (length < 30) return 0;
 
-  granule_rate = (ogg_int64_t) INT32_LE_AT(&header[12]);
+  granule_rate = (ogg_int64_t) int32_le_at(&header[12]);
 #ifdef DEBUG
   printf ("Got vorbis rate %d\n", (int)granule_rate);
 #endif
@@ -135,10 +130,13 @@ static int intlog(int num) {
 }
 #endif
 
+#define THEORA_VERSION(maj,min,rev) ((maj<<16)+(min<<8)+rev)
+
 static int
 auto_theora (OGGZ * oggz, long serialno, unsigned char * data, long length, void * user_data)
 {
   unsigned char * header = data;
+  int version;
   ogg_int32_t fps_numerator, fps_denominator;
   char keyframe_granule_shift = 0;
   int keyframe_shift;
@@ -146,8 +144,10 @@ auto_theora (OGGZ * oggz, long serialno, unsigned char * data, long length, void
   /* TODO: this should check against 42 for the relevant version numbers */
   if (length < 41) return 0;
 
-  fps_numerator = INT32_BE_AT(&header[22]);
-  fps_denominator = INT32_BE_AT(&header[26]);
+  version = THEORA_VERSION(header[7], header[8], header[9]);
+
+  fps_numerator = int32_be_at(&header[22]);
+  fps_denominator = int32_be_at(&header[26]);
 
   /* Very old theora versions used a value of 0 to mean 1.
    * Unfortunately theora hasn't incremented its version field,
@@ -174,6 +174,8 @@ auto_theora (OGGZ * oggz, long serialno, unsigned char * data, long length, void
 			OGGZ_AUTO_MULT * (ogg_int64_t)fps_denominator);
   oggz_set_granuleshift (oggz, serialno, keyframe_shift);
 
+  if (version > THEORA_VERSION(3,2,0))
+    oggz_set_first_granule (oggz, serialno, 1);
 
   oggz_stream_set_numheaders (oggz, serialno, 3);
 
@@ -197,8 +199,8 @@ auto_anxdata (OGGZ * oggz, long serialno, unsigned char * data, long length, voi
 
   if (length < 28) return 0;
 
-  granule_rate_numerator = INT64_LE_AT(&header[8]);
-  granule_rate_denominator = INT64_LE_AT(&header[16]);
+  granule_rate_numerator = int64_le_at(&header[8]);
+  granule_rate_denominator = int64_le_at(&header[16]);
 #ifdef DEBUG
   printf ("Got AnxData rate %lld/%lld\n", granule_rate_numerator,
 	  granule_rate_denominator);
@@ -247,7 +249,7 @@ auto_flac (OGGZ * oggz, long serialno, unsigned char * data, long length, void *
 
   oggz_set_granulerate (oggz, serialno, granule_rate, OGGZ_AUTO_MULT);
 
-  numheaders = INT16_BE_AT(&header[7]);
+  numheaders = int16_be_at(&header[7]);
   oggz_stream_set_numheaders (oggz, serialno, numheaders);
 
   return 1;
@@ -265,7 +267,7 @@ auto_oggpcm2 (OGGZ * oggz, long serialno, unsigned char * data, long length, voi
 
   if (length < 28) return 0;
 
-  granule_rate = (ogg_int64_t) INT32_BE_AT(&header[16]);
+  granule_rate = (ogg_int64_t) int32_be_at(&header[16]);
 #ifdef DEBUG
   printf ("Got OggPCM2 rate %d\n", (int)granule_rate);
 #endif
@@ -286,14 +288,14 @@ auto_celt (OGGZ * oggz, long serialno, unsigned char * data, long length, void *
 
   if (length < 56) return 0;
 
-  granule_rate = (ogg_int64_t) INT32_LE_AT(&header[40]);
+  granule_rate = (ogg_int64_t) int32_le_at(&header[40]);
 #ifdef DEBUG
   printf ("Got celt sample rate %d\n", (int)granule_rate);
 #endif
 
   oggz_set_granulerate (oggz, serialno, granule_rate, OGGZ_AUTO_MULT);
 
-  numheaders = (ogg_int64_t) INT32_LE_AT(&header[52]) + 2;
+  numheaders = (ogg_int64_t) int32_le_at(&header[52]) + 2;
   oggz_stream_set_numheaders (oggz, serialno, numheaders);
 
   return 1;
@@ -308,8 +310,8 @@ auto_cmml (OGGZ * oggz, long serialno, unsigned char * data, long length, void *
 
   if (length < 28) return 0;
 
-  granule_rate_numerator = INT64_LE_AT(&header[12]);
-  granule_rate_denominator = INT64_LE_AT(&header[20]);
+  granule_rate_numerator = int64_le_at(&header[12]);
+  granule_rate_denominator = int64_le_at(&header[20]);
   if (length > 28)
     granuleshift = (int)header[28];
   else
@@ -340,8 +342,8 @@ auto_kate (OGGZ * oggz, long serialno, unsigned char * data, long length, void *
 
   if (length < 64) return 0;
 
-  gps_numerator = INT32_LE_AT(&header[24]);
-  gps_denominator = INT32_LE_AT(&header[28]);
+  gps_numerator = int32_le_at(&header[24]);
+  gps_denominator = int32_le_at(&header[28]);
 
   granule_shift = (header[15]);
   numheaders = (header[11]);
@@ -369,7 +371,10 @@ auto_dirac (OGGZ * oggz, long serialno, unsigned char * data, long length, void
   info = oggz_malloc(sizeof(dirac_info));
   if (info == NULL) return -1;
 
-  dirac_parse_info(info, data, length);
+  if (dirac_parse_info(info, data, length) == -1) {
+    oggz_free (info);
+    return -1;
+  }
 
   /* the granulerate is twice the frame rate (in order to handle interlace) */
   oggz_set_granulerate (oggz, serialno,
@@ -393,13 +398,13 @@ auto_fisbone (OGGZ * oggz, long serialno, unsigned char * data, long length, voi
 
   if (length < 48) return 0;
 
-  fisbone_serialno = (long) INT32_LE_AT(&header[12]);
+  fisbone_serialno = (long) int32_le_at(&header[12]);
 
   /* Don't override an already assigned metric */
   if (oggz_stream_has_metric (oggz, fisbone_serialno)) return 1;
 
-  granule_rate_numerator = INT64_LE_AT(&header[20]);
-  granule_rate_denominator = INT64_LE_AT(&header[28]);
+  granule_rate_numerator = int64_le_at(&header[20]);
+  granule_rate_denominator = int64_le_at(&header[28]);
   granuleshift = (int)header[48];
 
 #ifdef DEBUG
@@ -565,7 +570,7 @@ auto_calc_theora(ogg_int64_t now, oggz_stream_t *stream, ogg_packet *op) {
   unsigned char first_byte;
   auto_calc_theora_info_t *info;
 
-  first_byte = op->packet[0];
+  first_byte = op->bytes == 0 ? 0x40 : op->packet[0];
 
   info = (auto_calc_theora_info_t *)stream->calculate_data;
 
@@ -1085,7 +1090,7 @@ const oggz_auto_contenttype_t oggz_auto_codec_ident[] = {
   {"Speex", 5, "Speex", auto_speex, auto_calc_speex, NULL},
   {"PCM     ", 8, "PCM", auto_oggpcm2, NULL, NULL},
   {"CMML\0\0\0\0", 8, "CMML", auto_cmml, NULL, NULL},
-  {"Annodex", 8, "Annodex", auto_annodex, NULL, NULL},
+  {"Annodex", 7, "Annodex", auto_annodex, NULL, NULL},
   {"fishead", 7, "Skeleton", auto_fishead, NULL, NULL},
   {"fLaC", 4, "Flac0", auto_flac0, auto_calc_flac, NULL},
   {"\177FLAC", 5, "Flac", auto_flac, auto_calc_flac, NULL},
