@@ -260,6 +260,16 @@ oggz_read_free_pbuffer_entry(OggzBufferedPacket *p)
   oggz_free(p);
 }
 
+OggzDListIterResponse
+oggz_read_free_pbuffers(void *elem)
+{
+  OggzBufferedPacket *p = (OggzBufferedPacket *)elem;
+
+  oggz_read_free_pbuffer_entry(p);
+
+  return DLIST_ITER_CONTINUE;
+}
+
 OggzDListIterResponse
 oggz_read_update_gp(void *elem) {
 
@@ -291,6 +301,7 @@ oggz_read_deliver_packet(void *elem) {
   OggzBufferedPacket *p = (OggzBufferedPacket *)elem;
   ogg_int64_t gp_stored;
   ogg_int64_t unit_stored;
+  int cb_ret;
 
   if (p->zp.pos.calc_granulepos == -1) {
     return DLIST_ITER_CANCEL;
@@ -305,11 +316,19 @@ oggz_read_deliver_packet(void *elem) {
     oggz_get_unit (p->oggz, p->serialno, p->zp.pos.calc_granulepos);
 
   if (p->stream->read_packet) {
-    p->stream->read_packet(p->oggz, &(p->zp), p->serialno, 
-                           p->stream->read_user_data);
+    if ((cb_ret = p->stream->read_packet(p->oggz, &(p->zp), p->serialno, 
+			       p->stream->read_user_data)) < 0) {
+      p->oggz->cb_next = cb_ret;
+      if (cb_ret == -1)
+        return DLIST_ITER_ERROR;
+    }
   } else if (p->reader->read_packet) {
-    p->reader->read_packet(p->oggz, &(p->zp), p->serialno, 
-                           p->reader->read_user_data);
+    if ((cb_ret = p->reader->read_packet(p->oggz, &(p->zp), p->serialno, 
+			       p->reader->read_user_data)) < 0) {
+      p->oggz->cb_next = cb_ret;
+      if (cb_ret == -1)
+        return DLIST_ITER_ERROR;
+    }
   }
 
   p->reader->current_granulepos = gp_stored;
@@ -465,7 +484,16 @@ oggz_read_sync (OGGZ * oggz)
               ogg_int64_t gp_stored = stream->last_granulepos;
               stream->last_packet = op;
               oggz_dlist_reverse_iter(oggz->packet_buffer, oggz_read_update_gp);
-              oggz_dlist_deliter(oggz->packet_buffer, oggz_read_deliver_packet);
+	      oggz->cb_next = 0;
+              if (oggz_dlist_deliter(oggz->packet_buffer, oggz_read_deliver_packet) == -1) {
+                return OGGZ_ERR_HOLE_IN_DATA;
+	      }
+	      if (oggz->cb_next > 0) {
+                cb_ret = oggz->cb_next;
+		oggz->cb_next = 0;
+		continue;
+	      }
+	      oggz->cb_next = 0;
 
               /* Fix up the stream granulepos. */
               stream->last_granulepos = gp_stored;
@@ -525,7 +553,10 @@ prepare_position:
     }
 
     /* If we've got a stop already, don't read more data in */
-    if (cb_ret == OGGZ_STOP_OK || cb_ret == OGGZ_STOP_ERR) return cb_ret;
+    if (cb_ret == OGGZ_STOP_OK || 
+	cb_ret == OGGZ_STOP_ERR || 
+	cb_ret == OGGZ_ERR_HOLE_IN_DATA) 
+      return cb_ret;
 
     if(oggz_read_get_next_page (oggz, &og) < 0)
       return OGGZ_READ_EMPTY; /* eof. leave uninitialized */
@@ -636,8 +667,9 @@ oggz_read (OGGZ * oggz, long n)
       nread += bytes_read;
       
       cb_ret = oggz_read_sync (oggz);
-      if (cb_ret == OGGZ_ERR_OUT_OF_MEMORY)
+      if (cb_ret == OGGZ_ERR_OUT_OF_MEMORY || cb_ret == OGGZ_ERR_HOLE_IN_DATA) {
         return cb_ret;
+      }
     }
   }
 
