@@ -34,7 +34,7 @@
 
 #include <string.h>
 
-#include <oggz/oggz.h>
+#include "oggz/oggz.h"
 
 #include "oggz_tests.h"
 
@@ -94,8 +94,9 @@ hungry (OGGZ * oggz, int empty, void * user_data)
 }
 
 static int
-read_packet (OGGZ * oggz, ogg_packet * op, long serialno, void * user_data)
+read_packet (OGGZ * oggz, oggz_packet * zp, long serialno, void * user_data)
 {
+  ogg_packet * op = &zp->op;
   static long packet_bytes_r = 1;
   static int iter = 0;
   static long b_o_s = 1;
