@@ -35,7 +35,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <oggz/oggz.h>
+#include "oggz/oggz.h"
 
 #include "oggz_tools.h"
 
