@@ -41,6 +41,7 @@
 
 #include "oggz-chop.h"
 #include "skeleton.h"
+#include "mimetypes.h"
 
 #ifdef OGG_H_CONST_CORRECT
 #define OGG_PAGE_CONST(x) (x)
@@ -276,7 +277,8 @@ track_state_advance_page_accum (OCTrackState * ts)
    */
   succ_continued = 1;
 
-  earliest_new = accum_size = oggz_table_size (ts->page_accum);
+  earliest_new = 0;
+  accum_size = oggz_table_size (ts->page_accum);
 
   /* Working backwards through the page accumulator ... */
   for (i = accum_size-1; i >= 0; i--) {
@@ -360,25 +362,6 @@ skeleton_write_packet (OCState * state, ogg_packet * op)
   return ret;
 }
 
-/* MIME types, for use in Skeleton. This must be in the same order as
- * enum OggzStreamContent defined in <oggz/oggz_constants.h> */
-const char * type_names[] = {
-  "video/theora",
-  "audio/vorbis",
-  "audio/speex",
-  "audio/x-oggpcm",
-  "text/cmml",
-  "application/x-annodex-2",
-  NULL, /* Skeleton */
-  "audio/flac",
-  "audio/flac",
-  NULL, /* AnxData */
-  "audio/celt",
-  "application/x-kate",
-  "video/dirac",
-  NULL /* UNKNOWN */
-};
-
 static int
 fisbone_init (OGGZ * oggz, OCState * state, OCTrackState * ts, long serialno)
 {
@@ -402,7 +385,7 @@ fisbone_init (OGGZ * oggz, OCState * state, OCTrackState * ts, long serialno)
     /* XXX: C99 */
 #define CONTENT_TYPE_FMT "Content-Type: %s\r\n"
     content_type = oggz_stream_get_content (oggz, serialno);
-    name = type_names[content_type];
+    name = mime_type_names[content_type];
     len = snprintf (NULL, 0, CONTENT_TYPE_FMT, name);
     if ((ts->fisbone.message_header_fields = malloc(len+1)) == NULL) {
       return -1;
@@ -609,22 +592,31 @@ read_plain (OGGZ * oggz, const ogg_page * og, long serialno, void * user_data)
 {
   OCState * state = (OCState *)user_data;
   OCTrackState * ts;
+  OCPageAccum * pa;
   double page_time;
   long gp;
+  int accum_size;
 
   ts = oggz_table_lookup (state->tracks, serialno);
+  accum_size = oggz_table_size (ts->page_accum);
 
   page_time = oggz_tell_units (oggz) / 1000.0;
 
 #ifdef DEBUG
   printf ("page_time: %g\tspan (%g, %g)\n", page_time, state->start, state->end);
-  printf ("\tpageno: %d, numheaders %d\n", ogg_page_pageno(og),
+  printf ("\tpageno: %ld, numheaders %d\n", ogg_page_pageno(og),
           oggz_stream_get_numheaders (oggz, serialno));
 #endif
 
   if (page_time < state->start) {
-    if ((gp = ogg_page_granulepos (OGG_PAGE_CONST(og))) != -1)
+    if ((gp = ogg_page_granulepos (OGG_PAGE_CONST(og))) == -1) {
+      /* Add a copy of this to the page accumulator */
+      pa = page_accum_new (og, page_time);
+      oggz_table_insert (ts->page_accum, accum_size, pa);
+    } else {
       ts->fisbone.start_granule = ogg_page_granulepos (OGG_PAGE_CONST(og));
+      track_state_remove_page_accum (ts);
+    }
   } else if (page_time >= state->start &&
       (state->end == -1 || page_time <= state->end)) {
 
@@ -784,13 +776,12 @@ read_headers (OGGZ * oggz, const ogg_page * og, long serialno, void * user_data)
     ts->headers_remaining -= ogg_page_packets (OGG_PAGE_CONST(og));
 
     if (ts->headers_remaining <= 0) {
+      ts->page_accum = oggz_table_new();
       if (state->start == 0.0 || oggz_get_granuleshift (oggz, serialno) == 0) {
         oggz_set_read_page (oggz, serialno, read_plain, state);
       } else if (content_type == OGGZ_CONTENT_DIRAC) {
-        ts->page_accum = oggz_table_new();
         oggz_set_read_page (oggz, serialno, read_dirac, state);
       } else {
-        ts->page_accum = oggz_table_new();
         oggz_set_read_page (oggz, serialno, read_gs, state);
       }
     }
@@ -861,7 +852,10 @@ chop (OCState * state)
     oggz = oggz_open (state->infilename, OGGZ_READ|OGGZ_AUTO);
   }
 
-  if (oggz == NULL) return -1;
+  if (oggz == NULL) {
+    perror (state->infilename);
+    return -1;
+  }
 
   if (!state->dry_run) {
     if (state->outfilename == NULL) {
