@@ -39,7 +39,7 @@
 #include <getopt.h>
 #include <errno.h>
 
-#include <oggz/oggz.h>
+#include "oggz/oggz.h"
 #include "oggz_tools.h"
 
 #include "skeleton.h"
@@ -274,6 +274,7 @@ static int
 ot_fisbone_print(OI_Info * info, OI_TrackInfo *oit) {
 
   char *allocated, *messages, *token;
+  size_t len;
   
   if (oit->has_fisbone) {
     printf("\n\tExtra information from Ogg Skeleton track:\n");
@@ -288,16 +289,24 @@ ot_fisbone_print(OI_Info * info, OI_TrackInfo *oit) {
     printf ("\n");
     printf("\tPreroll: %d\n", oit->fbInfo.preroll);
 
-    allocated = messages = _ogg_calloc(oit->fbInfo.current_header_size+1, sizeof(char));
+    len = oit->fbInfo.current_header_size+1;
+    allocated = messages = _ogg_calloc(len, sizeof(char));
     if (messages == NULL) return OIT_OOM;
-    strcpy(messages, oit->fbInfo.message_header_fields);
+    strncpy(messages, oit->fbInfo.message_header_fields, len);
+    messages[len-1] = '\0';
 
     printf("\tMessage Header Fields:\n");
     while (1) {
-      token = strsep(&messages, "\n\r");
+      token = strchr(messages, '\r');
+      if (token == NULL)
+        break;
+      *token = '\0';
       printf("\t %s", token);
-      if (messages == NULL)
-	break;
+
+      token++;
+      if (*token == '\n')
+        token++;
+      messages = token;
     }
     printf("\n");
     _ogg_free(allocated);
@@ -449,10 +458,11 @@ read_page_pass2 (OGGZ * oggz, const ogg_page * og, long serialno, void * user_da
 }
 
 static int
-read_packet_pass1 (OGGZ * oggz, ogg_packet * op, long serialno,
+read_packet_pass1 (OGGZ * oggz, oggz_packet * zp, long serialno,
 		   void * user_data)
 {
   OI_Info * info = (OI_Info *)user_data;
+  ogg_packet * op = &zp->op;
   OI_TrackInfo * oit;
 
   oit = oggz_table_lookup (info->tracks, serialno);
@@ -490,10 +500,11 @@ read_packet_pass1 (OGGZ * oggz, ogg_packet * op, long serialno,
 }
 
 static int
-read_packet_pass2 (OGGZ * oggz, ogg_packet * op, long serialno,
+read_packet_pass2 (OGGZ * oggz, oggz_packet * zp, long serialno,
 		   void * user_data)
 {
   OI_Info * info = (OI_Info *)user_data;
+  ogg_packet * op = &zp->op;
   OI_TrackInfo * oit;
   long deviation;
   
