@@ -49,7 +49,7 @@
 #  define PRId64 "I64d"
 #endif
 
-#include <oggz/oggz.h>
+#include "oggz/oggz.h"
 #include "oggz_tools.h"
 
 /* #define DEBUG */
@@ -122,9 +122,10 @@ filter_page (OGGZ * oggz, const ogg_page * og, long serialno, void * user_data)
 }
 
 static int
-read_packet (OGGZ * oggz, ogg_packet * op, long serialno, void * user_data)
+read_packet (OGGZ * oggz, oggz_packet * zp, long serialno, void * user_data)
 {
   OSData * osdata = (OSData *) user_data;
+  ogg_packet * op = &zp->op;
   double time_offset;
 
   /* calculate granuleshift for theora track */
