@@ -37,7 +37,7 @@
 #include <string.h>
 #include <getopt.h>
 
-#include <oggz/oggz.h>
+#include "oggz/oggz.h"
 
 #include "dirac.h"
 #include "oggz_tools_dirac.h"
@@ -135,14 +135,16 @@ ot_theora_info (unsigned char * data, long len)
 
   if (len < 41) return NULL;
 
-  buf = malloc (80);
+  buf = malloc (128);
 
   width = INT16_BE_AT(&data[15]);
   height = INT16_BE_AT(&data[18]);
 
-  snprintf (buf, 80,
+  snprintf (buf, 128,
+            "\tTheora-Version: %d.%d.%d\n"
 	    "\tVideo-Framerate: %.3f fps\n"
 	    "\tVideo-Width: %d\n\tVideo-Height: %d\n",
+            data[7], data[8], data[9],
 	    (double)INT32_BE_AT(&data[22])/ (double)INT32_BE_AT(&data[26]),
 	    width, height);
 
@@ -287,7 +289,11 @@ ot_dirac_info (unsigned char * data, long len)
   buf = malloc (80);
   info = malloc(sizeof(dirac_info));
 
-  dirac_parse_info(info, data, len);
+  if (dirac_parse_info(info, data, len) == -1) {
+    free (info);
+    free (buf);
+    return NULL;
+  }
 
   snprintf (buf, 80,
 	    "\tVideo-Framerate: %.3f fps\n"
